@@ -5,8 +5,7 @@
 
 */
 
-#ifndef RICHTEXTCOMPOSER_INSERTHTMLDIALOG_H
-#define RICHTEXTCOMPOSER_INSERTHTMLDIALOG_H
+#pragma once
 
 #include <QDialog>
 
@@ -28,7 +27,8 @@ public:
 private:
     friend class InsertHtmlDialogPrivate;
     InsertHtmlDialogPrivate *const d;
+    void readConfig();
+    void writeConfig();
 };
 }
 
-#endif
