@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2012-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2012-2021 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: LGPL-2.0-or-later
 
@@ -12,24 +12,25 @@
 
 #include <QCheckBox>
 #include <QDialogButtonBox>
-#include <QVBoxLayout>
 #include <QPushButton>
+#include <QVBoxLayout>
 
-namespace KPIMTextEdit {
+namespace KPIMTextEdit
+{
 class InsertImageDialogPrivate
 {
 public:
     InsertImageDialogPrivate(InsertImageDialog *qq)
         : q(qq)
     {
-        auto *vbox = new QVBoxLayout(q);
+        auto vbox = new QVBoxLayout(q);
         q->setWindowTitle(i18nc("@title:window", "Insert Image"));
 
         imageWidget = new InsertImageWidget(q);
         vbox->addWidget(imageWidget);
         q->connect(imageWidget, &InsertImageWidget::enableButtonOk, q, [this](bool b) {
-                _k_slotEnabledButtonChanged(b);
-            });
+            _k_slotEnabledButtonChanged(b);
+        });
         QDialogButtonBox *buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok | QDialogButtonBox::Cancel, q);
         okButton = buttonBox->button(QDialogButtonBox::Ok);
         okButton->setText(i18n("Insert"));
