@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2012-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2012-2021 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: LGPL-2.0-or-later
 
@@ -11,8 +11,8 @@
 #include <KLocalizedString>
 #include <KSeparator>
 
-#include <QPushButton>
 #include <QDialogButtonBox>
+#include <QPushButton>
 #include <QVBoxLayout>
 
 using namespace KPIMTextEdit;
@@ -24,7 +24,7 @@ public:
         : q(qq)
     {
         q->setWindowTitle(i18nc("@title:window", "Insert Table"));
-        auto *mainLayout = new QVBoxLayout(q);
+        auto mainLayout = new QVBoxLayout(q);
 
         insertTableWidget = new InsertTableWidget(q);
         mainLayout->addWidget(insertTableWidget);
