@@ -1,34 +1,22 @@
 /*
-   Copyright (C) 2013-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef PLAINTEXTEDITOR_H
-#define PLAINTEXTEDITOR_H
+#pragma once
 
 #include "kpimtextedit_export.h"
 
 #include <QPlainTextEdit>
 
-namespace Sonnet {
+namespace Sonnet
+{
 class Highlighter;
 class SpellCheckDecorator;
 }
-namespace KPIMTextEdit {
+namespace KPIMTextEdit
+{
 /**
  * @brief The PlainTextEditor class
  * @author Laurent Montel <montel@kde.org>
@@ -44,13 +32,7 @@ public:
     explicit PlainTextEditor(QWidget *parent = nullptr);
     ~PlainTextEditor() override;
 
-    enum SupportFeature {
-        None = 0,
-        Search = 1,
-        SpellChecking = 2,
-        TextToSpeech = 4,
-        AllowWebShortcut = 8
-    };
+    enum SupportFeature { None = 0, Search = 1, SpellChecking = 2, TextToSpeech = 4, AllowWebShortcut = 8 };
     Q_DECLARE_FLAGS(SupportFeatures, SupportFeature)
 
     void setSearchSupport(bool b);
@@ -94,6 +76,7 @@ private Q_SLOTS:
 
     void slotLanguageSelected();
     void slotToggleAutoSpellCheck();
+
 protected:
     virtual void addExtraMenuEntry(QMenu *menu, QPoint pos);
 
@@ -127,8 +110,8 @@ private:
     void highlightWord(int length, int pos);
     void deleteEndOfLine();
     void moveLineUpDown(bool moveUp);
+    void moveCursorBeginUpDown(bool moveUp);
     class PlainTextEditorPrivate;
     PlainTextEditorPrivate *const d;
 };
 }
-#endif // PLAINTEXTEDITOR_H
