@@ -1,35 +1,23 @@
 /*
-   Copyright (C) 2013-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef RICHTEXTEDITOR_H
-#define RICHTEXTEDITOR_H
+#pragma once
 
 #include "kpimtextedit_export.h"
 #include <QTextEdit>
 
 class QContextMenuEvent;
 class QMenu;
-namespace Sonnet {
+namespace Sonnet
+{
 class Highlighter;
 class SpellCheckDecorator;
 }
-namespace KPIMTextEdit {
+namespace KPIMTextEdit
+{
 /**
  * @brief The RichTextEditor class
  * @author Laurent Montel <montel@kde.org>
@@ -46,14 +34,7 @@ class KPIMTEXTEDIT_EXPORT RichTextEditor : public QTextEdit
 public:
     explicit RichTextEditor(QWidget *parent = nullptr);
     ~RichTextEditor() override;
-    enum SupportFeature {
-        None = 0,
-        Search = 1,
-        SpellChecking = 2,
-        TextToSpeech = 4,
-        AllowTab = 8,
-        AllowWebShortcut = 16
-    };
+    enum SupportFeature { None = 0, Search = 1, SpellChecking = 2, TextToSpeech = 4, AllowTab = 8, AllowWebShortcut = 16 };
     Q_DECLARE_FLAGS(SupportFeatures, SupportFeature)
 
     void setSearchSupport(bool b);
@@ -151,9 +132,9 @@ private:
     void highlightWord(int length, int pos);
     void checkSpelling(bool force);
     void moveLineUpDown(bool moveUp);
+    void moveCursorBeginUpDown(bool moveUp);
     class RichTextEditorPrivate;
     RichTextEditorPrivate *const d;
 };
 }
 
-#endif // RICHTEXTEDITOR_H
