@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2014-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2014-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -29,7 +29,7 @@ QLocale AbstractTextToSpeechConfigInterface::locale() const
 
 void AbstractTextToSpeechConfigInterface::setLocale(const QLocale &locale)
 {
-    Q_UNUSED(locale);
+    Q_UNUSED(locale)
 }
 
 QStringList AbstractTextToSpeechConfigInterface::availableEngines() const
@@ -44,5 +44,5 @@ QStringList AbstractTextToSpeechConfigInterface::availableVoices() const
 
 void AbstractTextToSpeechConfigInterface::setEngine(const QString &engineName)
 {
-    Q_UNUSED(engineName);
+    Q_UNUSED(engineName)
 }
