@@ -4,8 +4,7 @@
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef TEXTTOSPEECHACTIONS_H
-#define TEXTTOSPEECHACTIONS_H
+#pragma once
 
 #include "kpimtextedit_export.h"
 #include "texttospeechwidget.h"
@@ -44,4 +43,3 @@ private:
 };
 }
 
-#endif // TEXTTOSPEECHACTIONS_H
